@@ -15,6 +15,7 @@
 #include "actiongroup.h"
 #include "appinfo.h"
 #include "application.h"
+#include "applicationcommandline.h"
 #include "asyncinitable.h"
 #include "asyncresult.h"
 #include "bufferedinputstream.h"
@@ -95,6 +96,7 @@
 #include "unixfdmessage.h"
 #include "unixinputstream.h"
 #include "unixoutputstream.h"
+#include "unixsocketaddress.h"
 
 extern "C"
 {
@@ -103,6 +105,7 @@ extern "C"
 
 GType g_app_launch_context_get_type(void);
 GType g_application_get_type(void);
+GType g_application_command_line_get_type(void);
 GType g_buffered_input_stream_get_type(void);
 GType g_buffered_output_stream_get_type(void);
 GType g_cancellable_get_type(void);
@@ -166,6 +169,7 @@ GType g_unix_input_stream_get_type(void);
 #ifndef G_OS_WIN32
 GType g_unix_output_stream_get_type(void);
 #endif //G_OS_WIN32
+GType g_unix_socket_address_get_type(void);
 GType g_volume_monitor_get_type(void);
 
 //Declarations of the *_error_quark() functions:
@@ -179,6 +183,7 @@ GQuark g_resolver_error_quark(void);
 
 namespace Gio {  class AppLaunchContext_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class Application_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class ApplicationCommandLine_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class BufferedInputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class BufferedOutputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class Cancellable_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -242,6 +247,7 @@ namespace Gio {  class UnixInputStream_Class { public: static Glib::ObjectBase*
 #ifndef G_OS_WIN32
 namespace Gio {  class UnixOutputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 #endif //G_OS_WIN32
+namespace Gio {  class UnixSocketAddress_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class VolumeMonitor_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 
 namespace Gio { 
@@ -255,6 +261,7 @@ void wrap_init()
 // Map gtypes to gtkmm wrapper-creation functions:
   Glib::wrap_register(g_app_launch_context_get_type(), &Gio::AppLaunchContext_Class::wrap_new);
   Glib::wrap_register(g_application_get_type(), &Gio::Application_Class::wrap_new);
+  Glib::wrap_register(g_application_command_line_get_type(), &Gio::ApplicationCommandLine_Class::wrap_new);
   Glib::wrap_register(g_buffered_input_stream_get_type(), &Gio::BufferedInputStream_Class::wrap_new);
   Glib::wrap_register(g_buffered_output_stream_get_type(), &Gio::BufferedOutputStream_Class::wrap_new);
   Glib::wrap_register(g_cancellable_get_type(), &Gio::Cancellable_Class::wrap_new);
@@ -318,11 +325,13 @@ void wrap_init()
 #ifndef G_OS_WIN32
   Glib::wrap_register(g_unix_output_stream_get_type(), &Gio::UnixOutputStream_Class::wrap_new);
 #endif //G_OS_WIN32
+  Glib::wrap_register(g_unix_socket_address_get_type(), &Gio::UnixSocketAddress_Class::wrap_new);
   Glib::wrap_register(g_volume_monitor_get_type(), &Gio::VolumeMonitor_Class::wrap_new);
 
   // Register the gtkmm gtypes:
   Gio::AppLaunchContext::get_type();
   Gio::Application::get_type();
+  Gio::ApplicationCommandLine::get_type();
   Gio::BufferedInputStream::get_type();
   Gio::BufferedOutputStream::get_type();
   Gio::Cancellable::get_type();
@@ -386,6 +395,7 @@ void wrap_init()
 #ifndef G_OS_WIN32
   Gio::UnixOutputStream::get_type();
 #endif //G_OS_WIN32
+  Gio::UnixSocketAddress::get_type();
   Gio::VolumeMonitor::get_type();
 
 } // wrap_init()
